OccupiedStorage

Trait OccupiedStorage 

pub trait OccupiedStorage<const KEY: u32> {
    type WithData: OccupyStorage;
}
Trait describes that the storage KEY already is occupied by WithData type. Implementation of that trait for each storage field prevents the user from occupying the same storage cells.

Required Associated Types

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors