pub trait DefaultEnv {
// Provided method
fn env() -> EnvAccess<'static, DefaultEnvironment> { ... }
}Expand description
Each object has access to default environment via Self::env().
It can be used for interaction with host functions of the blockchain.
Provided Methods
fn env() -> EnvAccess<'static, DefaultEnvironment>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".